<?php
/* Tribe Events Calendar support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 1 - register filters, that add/remove lists items for the Theme Options
if (!function_exists('stephanie_king_tribe_events_theme_setup1')) {
	add_action( 'after_setup_theme', 'stephanie_king_tribe_events_theme_setup1', 1 );
	function stephanie_king_tribe_events_theme_setup1() {
		add_filter( 'stephanie_king_filter_list_sidebars', 'stephanie_king_tribe_events_list_sidebars' );
	}
}

// Theme init priorities:
// 3 - add/remove Theme Options elements
if (!function_exists('stephanie_king_tribe_events_theme_setup3')) {
	add_action( 'after_setup_theme', 'stephanie_king_tribe_events_theme_setup3', 3 );
	function stephanie_king_tribe_events_theme_setup3() {
		if (stephanie_king_exists_tribe_events()) {
		
			stephanie_king_storage_merge_array('options', '', array(
				// Section 'Tribe Events' - settings for show pages
				'events' => array(
					"title" => esc_html__('Events', 'stephanie-king'),
					"desc" => wp_kses_data( __('Select parameters to display the events pages', 'stephanie-king') ),
					"type" => "section"
					),
				'expand_content_events' => array(
					"title" => esc_html__('Expand content', 'stephanie-king'),
					"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'stephanie-king') ),
					"refresh" => false,
					"std" => 1,
					"type" => "checkbox"
					),
				'header_style_events' => array(
					"title" => esc_html__('Header style', 'stephanie-king'),
					"desc" => wp_kses_data( __('Select style to display the site header on the events pages', 'stephanie-king') ),
					"std" => 'inherit',
					"options" => array(),
					"type" => "select"
					),
				'header_position_events' => array(
					"title" => esc_html__('Header position', 'stephanie-king'),
					"desc" => wp_kses_data( __('Select position to display the site header on the events pages', 'stephanie-king') ),
					"std" => 'inherit',
					"options" => array(),
					"type" => "select"
					),
				'sidebar_widgets_events' => array(
					"title" => esc_html__('Sidebar widgets', 'stephanie-king'),
					"desc" => wp_kses_data( __('Select sidebar to show on the events pages', 'stephanie-king') ),
					"std" => 'tribe_events_widgets',
					"options" => array(),
					"type" => "select"
					),
				'sidebar_position_events' => array(
					"title" => esc_html__('Sidebar position', 'stephanie-king'),
					"desc" => wp_kses_data( __('Select position to show sidebar on the events pages', 'stephanie-king') ),
					"refresh" => false,
					"std" => 'left',
					"options" => array(),
					"type" => "select"
					),
				'hide_sidebar_on_single_events' => array(
					"title" => esc_html__('Hide sidebar on the single event', 'stephanie-king'),
					"desc" => wp_kses_data( __("Hide sidebar on the single event's page", 'stephanie-king') ),
					"std" => 0,
					"type" => "checkbox"
					),
				'footer_scheme_events' => array(
					"title" => esc_html__('Footer Color Scheme', 'stephanie-king'),
					"desc" => wp_kses_data( __('Select color scheme to decorate footer area', 'stephanie-king') ),
					"std" => 'dark',
					"options" => array(),
					"type" => "select"
					)
				)
			);
		}
	}
}

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('stephanie_king_tribe_events_theme_setup9')) {
	add_action( 'after_setup_theme', 'stephanie_king_tribe_events_theme_setup9', 9 );
	function stephanie_king_tribe_events_theme_setup9() {
		
		if (stephanie_king_exists_tribe_events()) {
			add_action( 'wp_enqueue_scripts', 								'stephanie_king_tribe_events_frontend_scripts', 1100 );
			add_filter( 'stephanie_king_filter_merge_styles',						'stephanie_king_tribe_events_merge_styles' );
			add_filter( 'stephanie_king_filter_post_type_taxonomy',				'stephanie_king_tribe_events_post_type_taxonomy', 10, 2 );
			if (!is_admin()) {
				add_filter( 'stephanie_king_filter_detect_blog_mode',				'stephanie_king_tribe_events_detect_blog_mode' );
				add_filter( 'stephanie_king_filter_get_post_categories', 			'stephanie_king_tribe_events_get_post_categories');
				add_filter( 'stephanie_king_filter_get_post_date',		 			'stephanie_king_tribe_events_get_post_date');
			} else {
				add_action( 'admin_enqueue_scripts',						'stephanie_king_tribe_events_admin_scripts' );
			}
		}
		if (is_admin()) {
			add_filter( 'stephanie_king_filter_tgmpa_required_plugins',			'stephanie_king_tribe_events_tgmpa_required_plugins' );
		}

	}
}

// Remove 'Tribe Events' section from Customizer
if (!function_exists('stephanie_king_tribe_events_customizer_register_controls')) {
	add_action( 'customize_register', 'stephanie_king_tribe_events_customizer_register_controls', 100 );
	function stephanie_king_tribe_events_customizer_register_controls( $wp_customize ) {
		$wp_customize->remove_panel( 'tribe_customizer');
	}
}

// Check if Tribe Events is installed and activated
if ( !function_exists( 'stephanie_king_exists_tribe_events' ) ) {
	function stephanie_king_exists_tribe_events() {
		return class_exists( 'Tribe__Events__Main' );
	}
}

// Return true, if current page is any tribe_events page
if ( !function_exists( 'stephanie_king_is_tribe_events_page' ) ) {
	function stephanie_king_is_tribe_events_page() {
		$rez = false;
		if (stephanie_king_exists_tribe_events())
			if (!is_search()) $rez = tribe_is_event() || tribe_is_event_query() || tribe_is_event_category() || tribe_is_event_venue() || tribe_is_event_organizer();
		return $rez;
	}
}

// Detect current blog mode
if ( !function_exists( 'stephanie_king_tribe_events_detect_blog_mode' ) ) {
	//Handler of the add_filter( 'stephanie_king_filter_detect_blog_mode', 'stephanie_king_tribe_events_detect_blog_mode' );
	function stephanie_king_tribe_events_detect_blog_mode($mode='') {
		if (stephanie_king_is_tribe_events_page())
			$mode = 'events';
		return $mode;
	}
}

// Return taxonomy for current post type
if ( !function_exists( 'stephanie_king_tribe_events_post_type_taxonomy' ) ) {
	//Handler of the add_filter( 'stephanie_king_filter_post_type_taxonomy',	'stephanie_king_tribe_events_post_type_taxonomy', 10, 2 );
	function stephanie_king_tribe_events_post_type_taxonomy($tax='', $post_type='') {
		if (stephanie_king_exists_tribe_events() && $post_type == Tribe__Events__Main::POSTTYPE)
			$tax = Tribe__Events__Main::TAXONOMY;
		return $tax;
	}
}

// Show categories of the current event
if ( !function_exists( 'stephanie_king_tribe_events_get_post_categories' ) ) {
	//Handler of the add_filter( 'stephanie_king_filter_get_post_categories', 		'stephanie_king_tribe_events_get_post_categories');
	function stephanie_king_tribe_events_get_post_categories($cats='') {
		if (get_post_type() == Tribe__Events__Main::POSTTYPE)
			$cats = stephanie_king_get_post_terms(', ', get_the_ID(), Tribe__Events__Main::TAXONOMY);
		return $cats;
	}
}

// Return date of the current event
if ( !function_exists( 'stephanie_king_tribe_events_get_post_date' ) ) {
	//Handler of the add_filter( 'stephanie_king_filter_get_post_date', 'stephanie_king_tribe_events_get_post_date');
	function stephanie_king_tribe_events_get_post_date($dt='') {
		if (get_post_type() == Tribe__Events__Main::POSTTYPE) {
			$dt = tribe_get_start_date(null, true, 'Y-m-d');
			$dt = sprintf($dt < date('Y-m-d') 
								? esc_html__('Started on %s', 'stephanie-king') 
								: esc_html__('Starting %s', 'stephanie-king'),
								date(get_option('date_format'), strtotime($dt)));
		}
		return $dt;
	}
}
	
// Enqueue Tribe Events admin scripts and styles
if ( !function_exists( 'stephanie_king_tribe_events_admin_scripts' ) ) {
	//Handler of the add_action( 'admin_enqueue_scripts', 'stephanie_king_tribe_events_admin_scripts' );
	function stephanie_king_tribe_events_admin_scripts() {

	}
}

// Enqueue Tribe Events custom scripts and styles
if ( !function_exists( 'stephanie_king_tribe_events_frontend_scripts' ) ) {
	//Handler of the add_action( 'wp_enqueue_scripts', 'stephanie_king_tribe_events_frontend_scripts', 1100 );
	function stephanie_king_tribe_events_frontend_scripts() {
		if (stephanie_king_is_tribe_events_page()) {
			if (stephanie_king_is_on(stephanie_king_get_theme_option('debug_mode')) && stephanie_king_get_file_dir('plugins/the-events-calendar/the-events-calendar.css')!='')
				wp_enqueue_style( 'stephanie-king-the-events-calendar',  stephanie_king_get_file_url('plugins/the-events-calendar/the-events-calendar.css'), array(), null );
				wp_enqueue_style( 'stephanie-king-the-events-calendar-images',  stephanie_king_get_file_url('css/the-events-calendar.css'), array(), null );
		}
	}
}

// Merge custom styles
if ( !function_exists( 'stephanie_king_tribe_events_merge_styles' ) ) {
	//Handler of the add_filter('stephanie_king_filter_merge_styles', 'stephanie_king_tribe_events_merge_styles');
	function stephanie_king_tribe_events_merge_styles($list) {
		$list[] = 'plugins/the-events-calendar/the-events-calendar.css';
		$list[] = 'css/the-events-calendar.css';
		return $list;
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'stephanie_king_tribe_events_tgmpa_required_plugins' ) ) {
	//Handler of the add_filter('stephanie_king_filter_tgmpa_required_plugins',	'stephanie_king_tribe_events_tgmpa_required_plugins');
	function stephanie_king_tribe_events_tgmpa_required_plugins($list=array()) {
		if (in_array('the-events-calendar', stephanie_king_storage_get('required_plugins')))
			$list[] = array(
					'name' 		=> esc_html__('Tribe Events Calendar', 'stephanie-king'),
					'slug' 		=> 'the-events-calendar',
					'required' 	=> false
				);
		return $list;
	}
}


// Add Tribe Events specific items into lists
//------------------------------------------------------------------------

// Add sidebar
if ( !function_exists( 'stephanie_king_tribe_events_list_sidebars' ) ) {
	//Handler of the add_filter( 'stephanie_king_filter_list_sidebars', 'stephanie_king_tribe_events_list_sidebars' );
	function stephanie_king_tribe_events_list_sidebars($list=array()) {
		$list['tribe_events_widgets'] = array(
											'name' => esc_html__('Tribe Events Widgets', 'stephanie-king'),
											'description' => esc_html__('Widgets to be shown on the Tribe Events pages', 'stephanie-king')
											);
		return $list;
	}
}

// Add plugin-specific colors and fonts to the custom CSS
if (stephanie_king_exists_tribe_events()) { require_once STEPHANIE_KING_THEME_DIR . 'plugins/the-events-calendar/the-events-calendar.styles.php'; }
?>